@@ -1,15 +1,19 @@
 /*
- * SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #pragma once
 #include "textautogeneratetext_export.h"
-class QDebug;
 #include <QObject>
 #include <TextAutoGenerateText/TextAutoGenerateMessage>
+class QDebug;
 namespace TextAutoGenerateText
 {
+/*!
+ * \brief The TextAutoGenerateImportChatBaseJob class
+ * \author Laurent Montel <montel@kde.org>
+ */
 class TEXTAUTOGENERATETEXT_EXPORT TextAutoGenerateImportChatBaseJob : public QObject
 {
     Q_OBJECT
@@ -20,20 +24,36 @@ public:
         [[nodiscard]] bool isValid() const;
     };
 
+    /*!
+     */
     explicit TextAutoGenerateImportChatBaseJob(QObject *parent = nullptr);
+    /*!
+     */
     ~TextAutoGenerateImportChatBaseJob() override;
 
+    /*!
+     */
     [[nodiscard]] ImportChatInfo info() const;
+    /*!
+     */
     void setInfo(const ImportChatInfo &newInfo);
 
+    /*!
+     */
     [[nodiscard]] bool canStart() const;
+    /*!
+     */
     void start();
 
 Q_SIGNALS:
-    void importDone();
+    /*!
+     */
+    void importDone(const QString &title, const QList<TextAutoGenerateText::TextAutoGenerateMessage> &msgs);
 
 protected:
-    virtual void exportChat() = 0;
+    /*!
+     */
+    virtual void importChat() = 0;
     ImportChatInfo mInfo;
 };
 }
