@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,9 @@
 #include "core/localdatabase/textautogeneratelocaldatabasemanager.h"
 #include "core/models/textautogeneratechatsmodel.h"
 #include "core/models/textautogeneratemessagesmodel.h"
+#include "core/textautogeneratefilecache.h"
 #include "core/textautogeneratesettings.h"
+#include "core/textautogeneratetextutils.h"
 #include "core/textautogeneratetoolcalljob.h"
 #include "core/tools/textautogeneratetexttoolpluginmanager.h"
 #include "textautogeneratechatsettings.h"
@@ -47,6 +49,7 @@ TextAutoGenerateManager::TextAutoGenerateManager(QObject *parent)
     , mTextAutoGenerateChatsModel(new TextAutoGenerateChatsModel(this))
     , mDatabaseManager(new TextAutoGenerateLocalDatabaseManager)
     , mTextAutoGenerateChatSettings(new TextAutoGenerateChatSettings(this))
+    , mTextAutoGenerateFileCache(new TextAutoGenerateFileCache)
     , mTextAutoGenerateTextInstancesManager(new TextAutoGenerateTextInstancesManager(this, this))
     , mTextAutoGenerateSettings(new TextAutoGenerateSettings())
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
@@ -183,7 +186,7 @@ void TextAutoGenerateManager::createNewChat(const QString &title)
     // Switch back to not archived list
     setShowArchived(false);
     TextAutoGenerateChat chat;
-    const QByteArray chatId = QUuid::createUuid().toByteArray(QUuid::Id128);
+    const QByteArray chatId = TextAutoGenerateTextUtils::generateUUid();
     chat.setIdentifier(chatId);
     chat.setTitle(title);
     // we don't need to initialize it. (new chat => no data)
@@ -384,6 +387,26 @@ bool TextAutoGenerateManager::cancelRequest(const QByteArray &chatId, const QMod
     return false;
 }
 
+void TextAutoGenerateManager::duplicateChat(const QByteArray &chatId)
+{
+    if (chatId.isEmpty()) {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "chatId is empty. It's a bug";
+        return;
+    }
+    auto messagesModel = messagesModelFromChatId(chatId);
+    const auto messages = messagesModel->messages();
+    createNewChat(); // TODO fix title
+#if 0
+    for (auto &msg : msgs) {
+        if (convertUuid.contains(msg.answerUuid())) {
+            msg.setAnswerUuid(convertUuid.value(msg.answerUuid()));
+        }
+    }
+#endif
+    qWarning() << " not implemented yet";
+    // TODO
+}
+
 void TextAutoGenerateManager::archiveDiscussion(const QByteArray &chatId, bool archive)
 {
     mTextAutoGenerateChatsModel->archiveDiscussion(chatId, archive);
@@ -571,6 +594,18 @@ void TextAutoGenerateManager::loadEngine()
     Q_EMIT loadEngineDone();
 }
 
+void TextAutoGenerateManager::importChat(const QString &title, const QList<TextAutoGenerateText::TextAutoGenerateMessage> &msgs)
+{
+    createNewChat(title);
+    auto messagesModel = messagesModelFromChatId(currentChatId());
+    if (messagesModel) {
+        messagesModel->setMessages(msgs);
+        saveCurrentChatInDataBase(currentChatId());
+    } else {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to import file";
+    }
+}
+
 void TextAutoGenerateManager::saveCurrentChatInDataBase(const QByteArray &chatId)
 {
     if (mSaveInDatabase) {
@@ -631,6 +666,11 @@ TextAutoGenerateLocalDatabaseManager *TextAutoGenerateManager::databaseManager()
     return mDatabaseManager.get();
 }
 
+QString TextAutoGenerateManager::generateAttachmentTemporaryFile(const QByteArray &attachmentId) const
+{
+    return mTextAutoGenerateFileCache->cacheFilePath(attachmentId);
+}
+
 void TextAutoGenerateManager::setDebug(bool newDebug)
 {
     mDebug = newDebug;
